import React, { createContext, use, useCallback, useMemo, useRef } from 'react';
import useArray from '../hooks/useArray';
export const ToastNotificationServiceContext = /*#__PURE__*/createContext();
export const ToastNotificationServiceProvider = props => {
  const {
    children,
    Component
  } = props;
  const idCounter = useRef(0);

  function modifiyProps() {
    const modifiedProps = { ...props
    };
    delete modifiedProps.children;
    return modifiedProps;
  }

  const {
    array: toastMessages,
    addItem,
    removeItem: hideToastNotification,
    clearItems: clearToastNotifications
  } = useArray();
  const appendIdInObject = useCallback(item => {
    const id = `item${idCounter.current++}`;
    const modifiedItem = {
      id,
      data: item
    };
    addItem(modifiedItem);
  }, [addItem]);
  const showToastNotification = useCallback(item => {
    appendIdInObject(item);
  }, [appendIdInObject]);
  const contextValue = useMemo(() => ({
    toastMessages,
    showToastNotification,
    hideToastNotification,
    clearToastNotifications
  }), [toastMessages, showToastNotification, hideToastNotification, clearToastNotifications]);
  return /*#__PURE__*/React.createElement(ToastNotificationServiceContext.Provider, {
    value: contextValue
  }, children, /*#__PURE__*/React.createElement(Component, {
    messages: toastMessages,
    hideToastNotification: hideToastNotification,
    clearToastNotifications: clearToastNotifications,
    ...modifiyProps()
  }));
};
export const ToastNotificationConsumer = ToastNotificationServiceContext.Consumer;
export default ToastNotificationServiceContext;