import { useState, useCallback, useRef } from 'react';
import { appendToArray, deleteFromArray, modifyArrayItem, emptyArray } from '../helpers/arrayCRUD';
import { DUMMY_ARRAY } from '../helpers/constant';

const useArray = function () {
  let initialArray = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DUMMY_ARRAY;
  const [array, setArray] = useState(initialArray);
  const addItem = useCallback(item => {
    setArray(prevArray => appendToArray({
      array: prevArray,
      item
    }));
  }, []);
  const removeItem = useCallback(id => {
    setArray(prevArray => deleteFromArray({
      array: prevArray,
      id
    }));
  }, []);
  const clearItems = useCallback(() => {
    setArray(emptyArray());
  }, []);
  const updateItem = useCallback((id, newItem) => {
    setArray(prevArray => modifyArrayItem({
      array: prevArray,
      id,
      newItem
    }));
  }, []);
  return {
    array,
    addItem,
    removeItem,
    clearItems,
    updateItem
  };
};

export default useArray;