import handleArrayCURD from './helpers/handleArrayCURD';
import { addCustomEventListener, removeCustomEventListener } from './helpers/eventDispatcher';
import { DOT_SERVICE_EVENT, DOT_SERVICE_EVENT_TYPE_SHOW_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_HIDE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_CLEAR_ALL_TOAST_NOTIFICATION } from './helpers/constant';

const useDOTToastNotificationService = () => {
  const [notifications, setNotification] = useState(DUMMY_ARRAY);
  const {
    addItem: _showToastNotification,
    removeItem: _hideToastNotification,
    clearItems: _clearToastNotifications,
    getArray: _getToastNotifications
  } = handleArrayCURD();
  const toastIdCounter = useRef(0);

  const handleService = event => {
    const {
      type,
      payload
    } = event.detail;

    switch (type) {
      case DOT_SERVICE_EVENT_TYPE_SHOW_TOAST_NOTIFICATION:
        const id = `toast${toastIdCounter.current++}`;
        const toastMessage = {
          id,
          data: payload
        };

        _showToastNotification(toastMessage);

        setNotification(_getToastNotifications());
        break;

      case DOT_SERVICE_EVENT_TYPE_HIDE_TOAST_NOTIFICATION:
        _hideToastNotification(payload.id);

        setNotification(_getToastNotifications());
        break;

      case DOT_SERVICE_EVENT_TYPE_CLEAR_ALL_TOAST_NOTIFICATION:
        _clearToastNotifications();

        setNotification(_getToastNotifications());
        break;

      default:
        console.error('No such service found in DOT Toast Notification Service');
        break;
    }
  };

  useEffect(() => {
    // Add event listener
    addCustomEventListener({
      eventName: DOT_SERVICE_EVENT,
      callback: handleService
    });
    return () => {
      // Return a cleanup function to remove the event listener
      removeCustomEventListener({
        eventName: DOT_SERVICE_EVENT,
        callback: handleService
      });
    };
  }, []);
  return {
    notifications
  };
};

export default useDOTToastNotificationService;