import { useCallback, useEffect, useMemo, useRef } from 'react';
import { cancelBubblingEffect } from '@zohodesk/components/es/utils/Common';
import getAttributeValues from '../helpers/getAttributeValues';
import { DUMMY_ARRAY, DUMMY_OBJECT } from '../helpers/constant';

const useEventService = properties => {
  const {
    attributes = DUMMY_ARRAY,
    keyAttribute,
    isRendered,
    onClick
  } = properties;
  const attributesValue = useRef(DUMMY_OBJECT);
  useEffect(() => {
    if (!isRendered) {
      attributesValue.current = DUMMY_OBJECT;
    }
  }, [isRendered]);
  const handleClick = useCallback(event => {
    cancelBubblingEffect(event);
    const target = event.target.getAttribute(keyAttribute) || event.target.closest(`[${keyAttribute}]`);

    if (target) {
      const attributeData = getAttributeValues({
        element: event.target,
        attributes
      });

      if (Object.keys(attributeData).length > 0) {
        attributesValue.current = attributeData;
      }

      if (typeof onClick === 'function') {
        onClick(event);
      }
    }
  }, [attributes, keyAttribute, onClick]);
  useEffect(() => {
    document.addEventListener('click', handleClick);
    return () => {
      document.removeEventListener('click', handleClick);
    };
  }, [handleClick]);
  const attributeValues = useMemo(() => attributesValue.current, [attributesValue.current]);
  return {
    attributeValues
  };
};

export default useEventService;