import { useState, useCallback } from 'react';
import { emptyObject, mergeObjects, updateObjectValue as replaceObjectValueHelper, removeObjectKeys as deleteObjectValueHelper } from '../helpers/objectCRUD';
import { DUMMY_OBJECT } from '../helpers/constant';

const useObject = function () {
  let initialObject = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DUMMY_OBJECT;
  const [object, setObjectState] = useState(initialObject);
  const setObjectValue = useCallback(newObject => {
    setObjectState(prevObject => mergeObjects({
      object: prevObject,
      newObject
    }));
  }, []);
  const clearObjectValue = useCallback(() => {
    setObjectState(emptyObject());
  }, []);
  const updateObjectValue = useCallback((key, value) => {
    setObjectState(prevObject => replaceObjectValueHelper({
      object: prevObject,
      key,
      value
    }));
  }, []);
  const removeObjectKeys = useCallback(key => {
    setObjectState(prevObject => deleteObjectValueHelper({
      object: prevObject,
      key
    }));
  }, []);
  return {
    object,
    setObjectValue,
    clearObjectValue,
    updateObjectValue,
    removeObjectKeys
  };
};

export default useObject;