import handleObjectCURD from './helpers/handleObjectCURD';
import { addCustomEventListener, removeCustomEventListener } from './helpers/eventDispatcher';
import { DOT_SERVICE_EVENT, DOT_SERVICE_EVENT_TYPE_SHOW_ATTACHMENT_VIEWER, DOT_SERVICE_EVENT_TYPE_HIDE_ATTACHMENT_VIEWER } from './helpers/constant';

const useDOTAttachmentViewerService = () => {
  const {
    object: attachment,
    setObjectValue: showAttachmentViewer,
    clearObjectValue: hideAttachmentViewer
  } = handleObjectCURD();

  const handleService = event => {
    const {
      type,
      payload
    } = event.detail;

    switch (type) {
      case DOT_SERVICE_EVENT_TYPE_SHOW_ATTACHMENT_VIEWER:
        showAttachmentViewer(payload);
        break;

      case DOT_SERVICE_EVENT_TYPE_HIDE_ATTACHMENT_VIEWER:
        hideAttachmentViewer();
        break;

      default:
        console.error('No such service found in DOT Attachment Viewer Service');
        break;
    }
  }; // Add event listener


  addCustomEventListener({
    eventName: DOT_SERVICE_EVENT,
    callback: handleService
  }); // Return a cleanup function to remove the event listener

  const cleanup = () => {
    removeCustomEventListener({
      eventName: DOT_SERVICE_EVENT,
      callback: handleService
    });
  };

  return {
    getAttachment: () => attachment,
    showAttachmentViewer,
    hideAttachmentViewer,
    cleanup
  };
};

export default useDOTAttachmentViewerService;