import handleArrayCURD from './helpers/handleArrayCURD';
import { addCustomEventListener, removeCustomEventListener } from './helpers/eventDispatcher';
import { DOT_SERVICE_EVENT, DOT_SERVICE_EVENT_TYPE_SHOW_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_HIDE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_CLEAR_ALL_TOAST_NOTIFICATION } from './helpers/constant';

const useDOTToastNotificationService = () => {
  const {
    array: toastNotifications,
    addItem: showToastNotification,
    removeItem: hideToastNotification,
    clearItems: clearToastNotifications
  } = handleArrayCURD();

  const handleService = event => {
    const {
      type,
      payload
    } = event.detail;

    switch (type) {
      case DOT_SERVICE_EVENT_TYPE_SHOW_TOAST_NOTIFICATION:
        showToastNotification(payload);
        break;

      case DOT_SERVICE_EVENT_TYPE_HIDE_TOAST_NOTIFICATION:
        hideToastNotification(payload.id);
        break;

      case DOT_SERVICE_EVENT_TYPE_CLEAR_ALL_TOAST_NOTIFICATION:
        clearToastNotifications();
        break;

      default:
        console.error('No such service found in DOT Toast Notification Service');
        break;
    }
  }; // Add event listener


  addCustomEventListener({
    eventName: DOT_SERVICE_EVENT,
    callback: handleService
  }); // Return a cleanup function to remove the event listener

  const cleanup = () => {
    removeCustomEventListener({
      eventName: DOT_SERVICE_EVENT,
      callback: handleService
    });
  };

  return {
    getToastNotifications: () => toastNotifications,
    showToastNotification,
    hideToastNotification,
    clearToastNotifications,
    cleanup
  };
};

export default useDOTToastNotificationService;