"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeCustomEventListener = exports.dispatchCustomEvent = exports.addCustomEventListener = void 0;

var _constant = require("./constant");

var eventListenersMap = new Map();

var dispatchCustomEvent = function dispatchCustomEvent(_ref) {
  var eventName = _ref.eventName,
      detail = _ref.detail,
      dispatchElementRef = _ref.dispatchElementRef;
  var event = new CustomEvent(eventName, {
    detail: detail
  });

  if (dispatchElementRef) {
    dispatchElementRef.dispatchEvent(event);
  } else {
    window.dispatchEvent(event);
  }
};

exports.dispatchCustomEvent = dispatchCustomEvent;

var addCustomEventListener = function addCustomEventListener(_ref2) {
  var eventName = _ref2.eventName,
      callback = _ref2.callback,
      dispatchElementRef = _ref2.dispatchElementRef;
  var target = dispatchElementRef || window;

  var listeners = eventListenersMap.get(target) || _constant.DUMMY_OBJECT;

  if (!listeners[eventName]) {
    target.addEventListener(eventName, callback);
    listeners[eventName] = callback;
    eventListenersMap.set(target, listeners);
  }
};

exports.addCustomEventListener = addCustomEventListener;

var removeCustomEventListener = function removeCustomEventListener(_ref3) {
  var eventName = _ref3.eventName,
      callback = _ref3.callback,
      dispatchElementRef = _ref3.dispatchElementRef;
  var target = dispatchElementRef || window;
  var listeners = eventListenersMap.get(target);

  if (listeners && listeners[eventName]) {
    target.removeEventListener(eventName, callback);
    delete listeners[eventName];

    if (Object.keys(listeners).length === 0) {
      eventListenersMap["delete"](target);
    } else {
      eventListenersMap.set(target, listeners);
    }
  }
};

exports.removeCustomEventListener = removeCustomEventListener;