"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.constructAttachmentUrl = constructAttachmentUrl;
exports.getViewURL = getViewURL;

var _Attachment = require("../../AttachmentViewer/Attachment");

function getViewURL(attachment, orgId) {
  var _attachment$href = attachment.href,
      href = _attachment$href === void 0 ? '' : _attachment$href;
  var name = attachment.name;
  var hasBrowserSupport = (0, _Attachment.isBrowserSupportedFile)(name);

  if (href.indexOf('/api/v1') !== -1) {
    if (href.indexOf('orgId') === -1) {
      href = "".concat(href, "?orgId=").concat(orgId);
      href += hasBrowserSupport ? '&inline=true' : '&inline=false';
    }

    return href; // eslint-disable-next-line no-else-return
  } else if (href.indexOf('/webdownload') !== -1) {
    var URLArr = href.split('?');

    if (URLArr.length === 1) {
      return href;
    }

    var URLSearchObj = new URLSearchParams(URLArr[1]);
    var clientMsg = JSON.parse(URLSearchObj.get('x-cli-msg'));
    clientMsg.inline = hasBrowserSupport ? 'true' : 'false';
    URLSearchObj.set('x-cli-msg', JSON.stringify(clientMsg));
    URLArr[1] = URLSearchObj.toString();
    return URLArr.join('?');
  }

  return "".concat(href);
}

function constructAttachmentUrl() {
  var href = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var orgId = arguments.length > 1 ? arguments[1] : undefined;
  var pos = href.indexOf('/api');
  var url = href;

  if (pos > -1 && url.indexOf('orgId=') === -1) {
    url = "".concat(url, "?orgId=").concat(orgId);
  }

  if (url.indexOf('/inlineattachments/') !== -1) {
    return url;
  } else if (url.indexOf('&mode=view') !== -1) {
    url = url.replace('&mode=view', '');
  } else if (url.indexOf('&inline=true') !== -1) {
    url = url.replace('&inline=true', '');
  } else if (url.indexOf(window.encodeURIComponent(',"inline":"true"')) !== -1) {
    url = url.replace(window.encodeURIComponent(',"inline":"true"'), '');
  } else if (url.indexOf('/ImageDisplayZSupport?') !== -1) {
    url = url.endsWith('&') ? url.concat('type=download') : url.concat('&type=download');
  } else if (url.indexOf('data:image') !== -1) {
    url = url.replace(/^data:image\/[^;]/, 'data:application/octet-stream');
  }

  return url;
}